==> gnue-reports_0.1.7.orig.tar.gz: gnue-reports-0.1.7/src/adapters/filters/Char/char/CHObjects/CHSummaryPage.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or (at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2004 Free Software Foundation
#
# $Id: CHSummaryPage.py 6706 2004-11-22 12:26:58Z btami $
#
# DESCRIPTION:
# Class that contains xml objects for GNUe Reports'
# "Char" markup.
#
# NOTES:
#

__all__ = ['CHSummaryPage']

from CHObject import CHObject, CHBand

class CHSummaryPage(CHObject, CHBand): 
  def __init__(self, parent=None, type='CHSummaryPage'):
    CHObject.__init__(self, parent, type=type)
    CHBand.__init__(self)


  def process(self, writer):
    if writer.PageFooter and (not writer.pageFooterDone):
      writer.PageFooter.process(writer)
    elif writer.currLine < writer.reportHeight:
      writer.newLine(writer.reportHeight - writer.currLine)
    writer.newPage()

      
    writer.pageHeaderDone = True
    writer.pageFooterDone = True

    for child in self._children:
      child.process(writer, self)

==> gnue-reports_0.1.8.orig.tar.gz: gnue-reports-0.1.8/src/adapters/filters/Char/char/CHObjects/CHSummaryPage.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or (at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2004 Free Software Foundation
#
# $Id: CHSummaryPage.py 6763 2004-11-30 23:36:21Z jcater $
#
# DESCRIPTION:
"""
Class that contains xml objects for GNUe Reports'
"Char" markup.
"""
# NOTES:
#

__all__ = ['CHSummaryPage']

from CHObject import CHObject, CHBand

class CHSummaryPage(CHObject, CHBand):
  def __init__(self, parent=None, type='CHSummaryPage'):
    CHObject.__init__(self, parent, type=type)
    self.height = parent.height
    CHBand.__init__(self)


  def process(self, writer):
    if writer.PageFooter and (not writer.pageFooterDone):
      writer.PageFooter.process(writer)
      writer.newPage()
    elif writer.currLine < writer.reportHeight:
      writer.printLines([""] * (writer.reportHeight - writer.currLine), self._type)

    writer.pageHeaderDone = True
    writer.pageFooterDone = True

    CHBand.process(self, writer)
